/*
 * qssl.cpp - Qt OpenSSL plugin
 * Copyright (C) 2001-2003  Justin Karneges
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef QSSL_P_H
#define QSSL_P_H

#include"qssl.h"

class _QSSL : public QSSL
{
public:
	_QSSL();
	~_QSSL();

	QSSLFilter *createFilter();
//! \if _hide_doc_
private:
	class QSSLPrivate *d;
//! \endif _hide_doc_
};

class _QSSLFilter : public QSSLFilter
{
	Q_OBJECT

public:
	_QSSLFilter();
	~_QSSLFilter();

	void reset();
	bool begin();

	// send data
	void send(const QByteArray &);
	// check/recv data
	bool isRecvData();
	QByteArray recv();

	// pass incoming socket data to this function
	void putIncomingSSLData(const QByteArray &);
	// check/read outgoing socket data with this function
	bool isOutgoingSSLData();
	QByteArray getOutgoingSSLData();

	void setSSLTrustedCertStoreDir(const QString &);

	void continueAfterWarning();

private slots:
	void sslUpdate();

private:
	enum { SSL_IDLE, SSL_CONNECT, SSL_HANDSHAKING, SSL_ACTIVE };
	void finishHandshake();
	void processSendQueue();
	void sslReadAll();
	void doError();
	void doWarning();
	QString sslErrMessage(int errcode);

	//! \if _hide_doc_
	class QSSLFilterPrivate *d;
	//! \endif
};

#endif
